# example2.c
#
# This example opens a data file, inserts data from the file into a
# newly created table containing several of the SQL Server datatypes,
# and binds and prints the results.
import sys
from mssqldb import *

import exutils

HEXLEN = 510
PLEN = 25 

print "Demo of SQL queries in a command batch\n"

# Initialize DB-Library.
if dbinit() == FAIL:
    sys.exit(1)

# Install the user-supplied error-handling and message-handling
# routines. They are defined at the bottom of this source file.
dberrhandle(exutils.err_handler)
dbmsghandle(exutils.msg_handler)
	
# Allocate and initialize the LOGINREC structure to be used to open a
# connection to SQL Server.
login = dblogin()
login.dbsetluser(exutils.USER)
login.dbsetlpwd(exutils.PASSWORD)
login.dbsetlapp("example2")

dbproc = login.dbopen(exutils.SERVER)

print "Creating the 'test' database."
dbproc.dbcmd("create database test")
dbproc.dbsqlexec()
while dbproc.dbresults() != NO_MORE_RESULTS:
    pass

dbproc.dbuse("test")

print "Creating the 'alltypes' table."

# Create a table that contains several SQL Server datatypes.
dbproc.dbcmd("create table alltypes ")
dbproc.dbcmd("(age tinyint,")
dbproc.dbcmd("userid smallint,")
dbproc.dbcmd("royalty int,")
dbproc.dbcmd("name char(25),")
dbproc.dbcmd("title_id varbinary(20),")
dbproc.dbcmd("us_citizen bit,")
dbproc.dbcmd("account float,")
dbproc.dbcmd("title varchar(20),")
dbproc.dbcmd("manager char(25))")
  
dbproc.dbsqlexec()
while dbproc.dbresults() != NO_MORE_RESULTS:
    pass

# Insert rows of data into the newly created table "alltypes".  We
# will read in the contents of the file and form an INSERT statement.
infile = open("datafile")

print "Inserting rows into the 'alltypes' table."

for cmdbuf in infile.readlines():
    dbproc.dbcmd("insert into alltypes \n")
    dbproc.dbcmd("values(%s)\n" % cmdbuf)

dbproc.dbsqlexec()

# Process the results of each of the INSERT statements.
while 1:
    return_code = dbproc.dbresults()
    if return_code == NO_MORE_RESULTS:
        break
    if return_code == FAIL:
        print "One of the insert statements FAILed."

print "Selecting rows from the 'alltypes' table:"

dbproc.dbcmd("select * from alltypes")
dbproc.dbsqlexec()

age = DataBuf(SQLINT1)
userid = DataBuf(SQLINT2)
royalty = DataBuf(SQLINT4)
name = DataBuf(SQLCHAR, PLEN)
title_id = DataBuf(SQLBINARY, PLEN)
us_citizen = DataBuf(SQLBIT)
account = DataBuf(SQLFLT8)
title = DataBuf(SQLCHAR, PLEN)
manager = DataBuf(SQLCHAR, PLEN)

id_buffer = DataBuf(SQLCHAR, HEXLEN)
while 1:
    return_code = dbproc.dbresults()
    if return_code == NO_MORE_RESULTS:
        break
    if return_code == SUCCEED:
        dbproc.dbbind(1, age, 0);
        dbproc.dbbind(2, userid, 0);
        dbproc.dbbind(3, royalty, 0);
        dbproc.dbbind(4, name, 0);
        dbproc.dbbind(5, title_id, 0);
        dbproc.dbbind(6, us_citizen, 0);
        dbproc.dbbind(7, account, 0);
        dbproc.dbbind(8, title, 0);
        dbproc.dbbind(9, manager, 0);

        while dbproc.dbnextrow() != NO_MORE_ROWS:
            title_id.len = dbproc.dbdatlen(5)
            id_buffer.len = -1
            dbproc.dbconvert(title_id, id_buffer)
            print "%d  %d  %d  %s  0x%s" \
                  % (age.get(), userid.get(), royalty.get(), name, id_buffer)
            print "%d  %8.2f  %s  %s" \
                  % (us_citizen.get(), account.get(), title, manager)
dbexit()
